@@ -1060,6 +1060,10 @@ ews_folder_count_notify_cb (CamelFolderSummary *folder_summary,
 	store_summary = ews_store->summary;
 	folder_id = camel_ews_store_summary_get_folder_id_from_name (ews_store->summary, camel_folder_get_full_name (folder));
 
+	/* this can happen on folder delete/unsubscribe, after folder summary clear */
+	if (!folder_id)
+		return;
+
 	if (g_strcmp0 (g_param_spec_get_name (param), "saved-count") == 0) {
 		count = camel_folder_summary_get_saved_count (folder_summary);
 		camel_ews_store_summary_set_folder_total (store_summary, folder_id, count);
@@ -1073,6 +1077,27 @@ ews_folder_count_notify_cb (CamelFolderSummary *folder_summary,
 	g_free (folder_id);
 }
 
+static gboolean
+folder_has_inbox_type (CamelEwsStore *ews_store,
+                       const gchar *folder_name)
+{
+	gchar *folder_id;
+	guint64 flags;
+
+	g_return_val_if_fail (CAMEL_IS_EWS_STORE (ews_store), FALSE);
+	g_return_val_if_fail (folder_name != NULL, FALSE);
+
+	folder_id = camel_ews_store_summary_get_folder_id_from_name (ews_store->summary, folder_name);
+	if (!folder_id)
+		return FALSE;
+
+	flags = camel_ews_store_summary_get_folder_flags (ews_store->summary, folder_id, NULL);
+
+	g_free (folder_id);
+
+	return (flags & CAMEL_FOLDER_TYPE_MASK) == CAMEL_FOLDER_TYPE_INBOX;
+}
+
 CamelFolder *
 camel_ews_folder_new (CamelStore *store,
                       const gchar *folder_name,
@@ -1120,11 +1145,20 @@ camel_ews_folder_new (CamelStore *store,
 		return NULL;
 	}
 
-	if (!g_ascii_strcasecmp (folder_name, "Inbox")) {
-		CamelStoreSettings *settings = CAMEL_STORE_SETTINGS (camel_service_get_settings (CAMEL_SERVICE (store)));
+	if (!g_ascii_strcasecmp (folder_name, "Inbox") ||
+	    folder_has_inbox_type (CAMEL_EWS_STORE (store), folder_name)) {
+		CamelSettings *settings;
+		gboolean filter_inbox;
 
-		if (camel_store_settings_get_filter_inbox (settings))
+		settings = camel_service_ref_settings (CAMEL_SERVICE (store));
+
+		filter_inbox = camel_store_settings_get_filter_inbox (
+			CAMEL_STORE_SETTINGS (settings));
+
+		if (filter_inbox)
 			folder->folder_flags |= CAMEL_FOLDER_FILTER_RECENT;
+
+		g_object_unref (settings);
 	}
 
 	ews_folder->search = camel_folder_search_new ();
@@ -1749,25 +1783,31 @@ ews_folder_constructed (GObject *object)
 	CamelService *service;
 	CamelFolder *folder;
 	const gchar *full_name;
-	const gchar *host;
-	const gchar *user;
 	gchar *description;
+	gchar *host;
+	gchar *user;
 
 	folder = CAMEL_FOLDER (object);
 	full_name = camel_folder_get_full_name (folder);
 	parent_store = camel_folder_get_parent_store (folder);
 
 	service = CAMEL_SERVICE (parent_store);
-	settings = camel_service_get_settings (service);
+
+	settings = camel_service_ref_settings (service);
 
 	network_settings = CAMEL_NETWORK_SETTINGS (settings);
-	host = camel_network_settings_get_host (network_settings);
-	user = camel_network_settings_get_user (network_settings);
+	host = camel_network_settings_dup_host (network_settings);
+	user = camel_network_settings_dup_user (network_settings);
+
+	g_object_unref (settings);
 
 	description = g_strdup_printf (
 		"%s@%s:%s", user, host, full_name);
 	camel_folder_set_description (folder, description);
 	g_free (description);
+
+	g_free (host);
+	g_free (user);
 }
 
 static void
