@@ -70,12 +70,15 @@ static gboolean	ews_store_construct	(CamelService *service, CamelSession *sessio
 					 CamelProvider *provider, GError **error);
 
 static void camel_ews_store_initable_init (GInitableIface *interface);
+static void camel_ews_subscribable_init (CamelSubscribableInterface *interface);
 static GInitableIface *parent_initable_interface;
 
 G_DEFINE_TYPE_WITH_CODE (
 	CamelEwsStore, camel_ews_store, CAMEL_TYPE_OFFLINE_STORE,
 	G_IMPLEMENT_INTERFACE (
-		G_TYPE_INITABLE, camel_ews_store_initable_init))
+		G_TYPE_INITABLE, camel_ews_store_initable_init)
+	G_IMPLEMENT_INTERFACE (
+		CAMEL_TYPE_SUBSCRIBABLE, camel_ews_subscribable_init))
 
 static void
 ews_migrate_to_user_cache_dir (CamelService *service)
@@ -193,6 +196,162 @@ ews_store_construct (CamelService *service,
 	return TRUE;
 }
 
+void
+camel_ews_store_ensure_virtual_folders (CamelEwsStore *ews_store)
+{
+	gboolean needs_foreign = FALSE, has_foreign = FALSE;
+	GSList *folders, *iter;
+	GHashTable *children_count;
+	GHashTableIter tab_iter;
+	gpointer key, value;
+
+	g_return_if_fail (CAMEL_IS_EWS_STORE (ews_store));
+
+	folders = camel_ews_store_summary_get_folders (ews_store->summary, NULL);
+	if (!folders)
+		return;
+
+	children_count = g_hash_table_new (g_str_hash, g_str_equal);
+
+	for (iter = folders; iter; iter = iter->next) {
+		const gchar *fid = iter->data;
+		GError *error = NULL;
+
+		if (!fid)
+			continue;
+
+		if (g_str_has_prefix (fid, "ForeignMailbox::") &&
+		    !g_hash_table_contains (children_count, fid))
+			g_hash_table_insert (children_count, (gpointer) fid, GINT_TO_POINTER (0));
+
+		if (!has_foreign && g_str_equal (fid, EWS_FOREIGN_FOLDER_ROOT_ID))
+			has_foreign = TRUE;
+		else if (camel_ews_store_summary_get_foreign (ews_store->summary, fid, &error) && !error) {
+			gchar *pfid;
+
+			needs_foreign = TRUE;
+
+			pfid = camel_ews_store_summary_get_parent_folder_id (ews_store->summary, fid, NULL);
+			if (pfid && g_str_has_prefix (pfid, "ForeignMailbox::")) {
+				gint count = GPOINTER_TO_INT (g_hash_table_lookup (children_count, pfid));
+
+				g_hash_table_insert (children_count, (gpointer) pfid, GINT_TO_POINTER (count + 1));
+			}
+		}
+
+		g_clear_error (&error);
+	}
+
+	g_hash_table_iter_init (&tab_iter, children_count);
+	while (g_hash_table_iter_next (&tab_iter, &key, &value)) {
+		gint count = GPOINTER_TO_INT (value);
+
+		if (!count) {
+			CamelFolderInfo *fi;
+
+			fi = camel_ews_utils_build_folder_info (ews_store, key);
+			camel_ews_store_summary_remove_folder (ews_store->summary, key, NULL);
+
+			camel_subscribable_folder_unsubscribed (CAMEL_SUBSCRIBABLE (ews_store), fi);
+			camel_store_folder_deleted (CAMEL_STORE (ews_store), fi);
+			camel_folder_info_free (fi);
+		}
+	}
+
+	g_hash_table_destroy (children_count);
+
+	if (needs_foreign && !has_foreign) {
+		gchar *use_name = NULL;
+		gchar *tmp_fid;
+		gint counter = 0;
+
+		tmp_fid = camel_ews_store_summary_get_folder_id_from_name (
+			ews_store->summary, EWS_FOREIGN_FOLDER_ROOT_DISPLAY_NAME);
+		while (tmp_fid) {
+			counter++;
+
+			g_free (tmp_fid);
+			g_free (use_name);
+
+			/* Translators: This composes a "Foreign Folders" folder name for case when
+			 * user has such in his store already. The %s is replaced with "Foreign Folders",
+			 * the %d with counter, thus it composes name like "Foreign Folders_1"
+			*/
+			use_name = g_strdup_printf (
+				C_("ForeignFolders", "%s_%d"),
+				EWS_FOREIGN_FOLDER_ROOT_DISPLAY_NAME, counter);
+
+			tmp_fid = camel_ews_store_summary_get_folder_id_from_name (ews_store->summary, use_name);
+		}
+
+		camel_ews_store_summary_new_folder (
+			ews_store->summary,
+			EWS_FOREIGN_FOLDER_ROOT_ID, NULL, NULL,
+			use_name ? use_name : EWS_FOREIGN_FOLDER_ROOT_DISPLAY_NAME,
+			E_EWS_FOLDER_TYPE_MAILBOX,
+			CAMEL_FOLDER_SYSTEM | CAMEL_FOLDER_NOSELECT,
+			0, FALSE);
+
+		g_free (use_name);
+	} else if (has_foreign && !needs_foreign) {
+		CamelFolderInfo *fi;
+
+		fi = camel_ews_utils_build_folder_info (ews_store, EWS_FOREIGN_FOLDER_ROOT_ID);
+		camel_ews_store_summary_remove_folder (ews_store->summary, EWS_FOREIGN_FOLDER_ROOT_ID, NULL);
+
+		camel_subscribable_folder_unsubscribed (CAMEL_SUBSCRIBABLE (ews_store), fi);
+		camel_store_folder_deleted (CAMEL_STORE (ews_store), fi);
+		camel_folder_info_free (fi);
+	}
+
+	camel_ews_store_summary_rebuild_hashes (ews_store->summary);
+	camel_ews_store_summary_save (ews_store->summary, NULL);
+
+	g_slist_free_full (folders, g_free);
+}
+
+void
+camel_ews_store_ensure_unique_path (CamelEwsStore *ews_store,
+                                    gchar **ppath)
+{
+	gboolean done;
+	guint counter = 0;
+	gchar *base_path = NULL;
+
+	g_return_if_fail (CAMEL_IS_EWS_STORE (ews_store));
+	g_return_if_fail (ews_store->summary != NULL);
+	g_return_if_fail (ppath != NULL);
+	g_return_if_fail (*ppath != NULL);
+
+	done = FALSE;
+	while (!done) {
+		gchar *fid;
+
+		done = TRUE;
+
+		fid = camel_ews_store_summary_get_folder_id_from_name (ews_store->summary, *ppath);
+		if (fid) {
+			g_free (fid);
+
+			done = FALSE;
+			counter++;
+			if (!counter) {
+				g_debug ("%s: Counter overflow", G_STRFUNC);
+				break;
+			}
+
+			if (!base_path)
+				base_path = *ppath;
+			else
+				g_free (*ppath);
+
+			*ppath = g_strdup_printf ("%s_%u", base_path, counter);
+		}
+	}
+
+	g_free (base_path);
+}
+
 static void
 ews_update_folder_hierarchy (CamelEwsStore *ews_store,
                              gchar *sync_state,
@@ -202,6 +361,8 @@ ews_update_folder_hierarchy (CamelEwsStore *ews_store,
                              GSList *folders_updated)
 {
 	ews_utils_sync_folders (ews_store, folders_created, folders_deleted, folders_updated);
+	camel_ews_store_ensure_virtual_folders (ews_store);
+
 	camel_ews_store_summary_store_string_val (ews_store->summary, "sync_state", sync_state);
 	camel_ews_store_summary_save (ews_store->summary, NULL);
 
@@ -262,8 +423,18 @@ ews_disconnect_sync (CamelService *service,
 
 	/* TODO cancel all operations in the connection */
 	if (ews_store->priv->connection != NULL) {
-		g_signal_handlers_disconnect_by_data (
-			camel_service_get_settings (service), service);
+		CamelSettings *settings;
+
+		/* FIXME This is somewhat broken, since the CamelSettings
+		 *       instance returned here may not be the same instance
+		 *       that we connected a signal handler to.  Need to keep
+		 *       our own reference to that CamelSettings instance, or
+		 *       better yet avoid connecting signal handlers to it in
+		 *       the first place. */
+		settings = camel_service_ref_settings (service);
+		g_signal_handlers_disconnect_by_data (settings, service);
+		g_object_unref (settings);
+
 		e_ews_connection_set_password (
 			ews_store->priv->connection, NULL);
 		g_object_unref (ews_store->priv->connection);
@@ -355,7 +526,7 @@ ews_authenticate_sync (CamelService *service,
 		return CAMEL_AUTHENTICATION_ERROR;
 	}
 
-	settings = camel_service_get_settings (service);
+	settings = camel_service_ref_settings (service);
 
 	ews_settings = CAMEL_EWS_SETTINGS (settings);
 	hosturl = camel_ews_settings_dup_hosturl (ews_settings);
@@ -365,6 +536,8 @@ ews_authenticate_sync (CamelService *service,
 
 	g_free (hosturl);
 
+	g_object_unref (settings);
+
 	/* XXX We need to run some operation that requires authentication
 	 *     but does not change any server-side state, so we can check
 	 *     the error status and determine if our password is valid.
@@ -600,11 +773,11 @@ ews_folder_hierarchy_ready_cb (GObject *obj,
 		g_mutex_unlock (priv->get_finfo_lock);
 		goto exit;
 	}
+	g_mutex_lock (priv->get_finfo_lock);
 	ews_update_folder_hierarchy (
 		ews_store, sync_state, includes_last_folder,
 		folders_created, folders_deleted, folders_updated);
 
-	g_mutex_lock (priv->get_finfo_lock);
 	ews_store->priv->last_refresh_time = time (NULL);
 	g_mutex_unlock (priv->get_finfo_lock);
 
@@ -660,12 +833,22 @@ ews_get_folder_info_sync (CamelStore *store,
 	gboolean success;
 	GError *local_error = NULL;
 
+	if ((flags & CAMEL_STORE_FOLDER_INFO_SUBSCRIPTION_LIST) != 0) {
+		g_set_error_literal (
+			error, CAMEL_ERROR, CAMEL_ERROR_GENERIC,
+			_("Cannot list folders available for subscription of Exchange Web Services account, "
+			"use 'Subscribe to folder of other user' context menu option above the account node "
+			"in the folder tree instead."));
+		return NULL;
+	}
+
 	ews_store = (CamelEwsStore *) store;
 	priv = ews_store->priv;
 
 	g_mutex_lock (priv->get_finfo_lock);
 	if (!(camel_offline_store_get_online (CAMEL_OFFLINE_STORE (store))
 	      && camel_service_connect_sync ((CamelService *) store, cancellable, error))) {
+		camel_ews_store_ensure_virtual_folders (ews_store);
 		g_mutex_unlock (priv->get_finfo_lock);
 		goto offline;
 	}
@@ -736,6 +919,24 @@ ews_create_folder_sync (CamelStore *store,
 	gboolean success;
 	GError *local_error = NULL;
 
+	if (parent_name && *parent_name)
+		full_name = g_strdup_printf ("%s/%s", parent_name, folder_name);
+	else
+		full_name = g_strdup (folder_name);
+
+	fid = camel_ews_store_summary_get_folder_id_from_name (ews_summary, full_name);
+	if (fid) {
+		g_free (fid);
+		g_set_error (
+			error, CAMEL_ERROR, CAMEL_ERROR_GENERIC,
+			_("Cannot create folder '%s', folder already exists"),
+			full_name);
+		g_free (full_name);
+		return NULL;
+	}
+
+	g_free (full_name);
+
 	/* Get Parent folder ID */
 	if (parent_name && parent_name[0]) {
 		fid = camel_ews_store_summary_get_folder_id_from_name (
@@ -747,6 +948,16 @@ ews_create_folder_sync (CamelStore *store,
 				parent_name);
 			return NULL;
 		}
+
+		if (g_str_equal (fid, EWS_FOREIGN_FOLDER_ROOT_ID)) {
+			g_free (fid);
+
+			g_set_error (
+				error, CAMEL_ERROR, CAMEL_ERROR_GENERIC,
+				_("Cannot create folder under '%s', it is used for folders of other users only"),
+				parent_name);
+			return NULL;
+		}
 	}
 
 	if (!camel_ews_store_connected (ews_store, error)) {
@@ -782,11 +993,12 @@ ews_create_folder_sync (CamelStore *store,
 		fid, folder_id->change_key,
 		folder_name,
 		E_EWS_FOLDER_TYPE_MAILBOX,
-		0, 0);
+		0, 0, FALSE);
 	fi = camel_ews_utils_build_folder_info (ews_store, folder_id->id);
 	e_ews_folder_id_free (folder_id);
 
 	camel_store_folder_created (store, fi);
+	camel_subscribable_folder_subscribed (CAMEL_SUBSCRIBABLE (ews_store), fi);
 
 	g_free (full_name);
 	g_free (fid);
@@ -803,7 +1015,6 @@ ews_delete_folder_sync (CamelStore *store,
 	CamelEwsStoreSummary *ews_summary = ews_store->summary;
 	gchar *fid;
 	CamelFolderInfo *fi = NULL;
-	EEwsConnection *connection;
 	gboolean success;
 	GError *local_error = NULL;
 
@@ -816,20 +1027,38 @@ ews_delete_folder_sync (CamelStore *store,
 		return FALSE;
 	}
 
+	if (g_str_equal (fid, EWS_FOREIGN_FOLDER_ROOT_ID)) {
+		g_free (fid);
+
+		g_set_error (
+			error, CAMEL_ERROR, CAMEL_ERROR_GENERIC,
+			_("Cannot remove folder '%s', it is used for folders of other users only"),
+			folder_name);
+		return FALSE;
+	}
+
 	if (!camel_ews_store_connected (ews_store, error)) {
 		g_free (fid);
 		return FALSE;
 	}
 
-	connection = camel_ews_store_ref_connection (ews_store);
+	if (camel_ews_store_summary_get_foreign (ews_store->summary, fid, NULL)) {
+		/* do not delete foreign folders,
+		 * just remove them from local store */
+		success = TRUE;
+	} else {
+		EEwsConnection *connection;
 
-	success = e_ews_connection_delete_folder_sync (
-		connection,
-		EWS_PRIORITY_MEDIUM,
-		fid, FALSE, "HardDelete",
-		cancellable, &local_error);
+		connection = camel_ews_store_ref_connection (ews_store);
 
-	g_object_unref (connection);
+		success = e_ews_connection_delete_folder_sync (
+			connection,
+			EWS_PRIORITY_MEDIUM,
+			fid, FALSE, "HardDelete",
+			cancellable, &local_error);
+
+		g_object_unref (connection);
+	}
 
 	if (!success) {
 		camel_ews_store_maybe_disconnect (ews_store, local_error);
@@ -841,11 +1070,15 @@ ews_delete_folder_sync (CamelStore *store,
 	fi = camel_ews_utils_build_folder_info (ews_store, fid);
 	camel_ews_store_summary_remove_folder (ews_summary, fid, error);
 
+	camel_subscribable_folder_unsubscribed (CAMEL_SUBSCRIBABLE (ews_store), fi);
 	camel_store_folder_deleted (store, fi);
 	camel_folder_info_free (fi);
 
 	g_free (fid);
 
+	camel_ews_store_ensure_virtual_folders (ews_store);
+	camel_ews_store_summary_save (ews_store->summary, NULL);
+
 	return TRUE;
 }
 
@@ -1032,21 +1265,29 @@ ews_get_name (CamelService *service,
 {
 	CamelNetworkSettings *network_settings;
 	CamelSettings *settings;
-	const gchar *host;
-	const gchar *user;
+	gchar *name;
+	gchar *host;
+	gchar *user;
 
-	settings = camel_service_get_settings (service);
+	settings = camel_service_ref_settings (service);
 
 	network_settings = CAMEL_NETWORK_SETTINGS (settings);
-	host = camel_network_settings_get_host (network_settings);
-	user = camel_network_settings_get_user (network_settings);
+	host = camel_network_settings_dup_host (network_settings);
+	user = camel_network_settings_dup_user (network_settings);
+
+	g_object_unref (settings);
 
 	if (brief)
-		return g_strdup_printf (
+		name = g_strdup_printf (
 			_("Exchange server %s"), host);
 	else
-		return g_strdup_printf (
+		name = g_strdup_printf (
 			_("Exchange service for %s on %s"), user, host);
+
+	g_free (host);
+	g_free (user);
+
+	return name;
 }
 
 EEwsConnection *
@@ -1067,10 +1308,9 @@ camel_ews_store_ref_connection (CamelEwsStore *ews_store)
 }
 
 static CamelFolder *
-ews_get_folder_by_type_sync (CamelStore *store,
-                             guint32 folder_type,
-                             GCancellable *cancellable,
-                             GError **error)
+ews_get_trash_folder_sync (CamelStore *store,
+                           GCancellable *cancellable,
+                           GError **error)
 {
 	CamelEwsStore *ews_store;
 	CamelFolder *folder = NULL;
@@ -1079,14 +1319,22 @@ ews_get_folder_by_type_sync (CamelStore *store,
 	g_return_val_if_fail (CAMEL_IS_EWS_STORE (store), NULL);
 
 	ews_store = CAMEL_EWS_STORE (store);
-	folder_id = camel_ews_store_summary_get_folder_id_from_folder_type (ews_store->summary, folder_type);
+	folder_id = camel_ews_store_summary_get_folder_id_from_folder_type (
+		ews_store->summary, CAMEL_FOLDER_TYPE_TRASH);
 
-	if (!folder_id)
+	if (folder_id == NULL) {
+		g_set_error (
+			error, CAMEL_STORE_ERROR,
+			CAMEL_STORE_ERROR_NO_FOLDER,
+			_("Could not locate Trash folder"));
 		return NULL;
+	}
 
-	folder_name = camel_ews_store_summary_get_folder_full_name (ews_store->summary, folder_id, NULL);
+	folder_name = camel_ews_store_summary_get_folder_full_name (
+		ews_store->summary, folder_id, NULL);
 
-	folder = ews_get_folder_sync (store, folder_name, 0, cancellable, error);
+	folder = ews_get_folder_sync (
+		store, folder_name, 0, cancellable, error);
 
 	g_free (folder_name);
 	g_free (folder_id);
@@ -1094,20 +1342,39 @@ ews_get_folder_by_type_sync (CamelStore *store,
 	return folder;
 }
 
-static CamelFolder *
-ews_get_trash_folder_sync (CamelStore *store,
-                           GCancellable *cancellable,
-                           GError **error)
-{
-	return ews_get_folder_by_type_sync (store, CAMEL_FOLDER_TYPE_TRASH, cancellable, error);
-}
-
 static CamelFolder *
 ews_get_junk_folder_sync (CamelStore *store,
                           GCancellable *cancellable,
                           GError **error)
 {
-	return ews_get_folder_by_type_sync (store, CAMEL_FOLDER_TYPE_JUNK, cancellable, error);
+	CamelEwsStore *ews_store;
+	CamelFolder *folder = NULL;
+	gchar *folder_id, *folder_name;
+
+	g_return_val_if_fail (CAMEL_IS_EWS_STORE (store), NULL);
+
+	ews_store = CAMEL_EWS_STORE (store);
+	folder_id = camel_ews_store_summary_get_folder_id_from_folder_type (
+		ews_store->summary, CAMEL_FOLDER_TYPE_JUNK);
+
+	if (folder_id == NULL) {
+		g_set_error (
+			error, CAMEL_STORE_ERROR,
+			CAMEL_STORE_ERROR_NO_FOLDER,
+			_("Could not locate Junk folder"));
+		return NULL;
+	}
+
+	folder_name = camel_ews_store_summary_get_folder_full_name (
+		ews_store->summary, folder_id, NULL);
+
+	folder = ews_get_folder_sync (
+		store, folder_name, 0, cancellable, error);
+
+	g_free (folder_name);
+	g_free (folder_id);
+
+	return folder;
 }
 
 static gboolean
@@ -1115,12 +1382,115 @@ ews_can_refresh_folder (CamelStore *store,
                         CamelFolderInfo *info,
                         GError **error)
 {
+	CamelSettings *settings;
+	CamelEwsSettings *ews_settings;
+	gboolean check_all;
+
 	/* Skip unselectable folders from automatic refresh */
-	if (info && (info->flags & CAMEL_FOLDER_NOSELECT) != 0) return FALSE;
+	if (info && (info->flags & CAMEL_FOLDER_NOSELECT) != 0)
+		return FALSE;
+
+	settings = camel_service_ref_settings (CAMEL_SERVICE (store));
+
+	ews_settings = CAMEL_EWS_SETTINGS (settings);
+	check_all = camel_ews_settings_get_check_all (ews_settings);
+
+	g_object_unref (settings);
+
+	if (check_all)
+		return TRUE;
 
 	/* Delegate decision to parent class */
-	return CAMEL_STORE_CLASS (camel_ews_store_parent_class)->can_refresh_folder (store, info, error) ||
-		camel_ews_settings_get_check_all (CAMEL_EWS_SETTINGS (camel_service_get_settings (CAMEL_SERVICE (store))));
+	return CAMEL_STORE_CLASS (camel_ews_store_parent_class)->
+		can_refresh_folder (store, info, error);
+}
+
+static gboolean
+ews_store_folder_is_subscribed (CamelSubscribable *subscribable,
+                                const gchar *folder_name)
+{
+	CamelEwsStore *ews_store = CAMEL_EWS_STORE (subscribable);
+	gchar *fid;
+	gboolean truth = FALSE;
+	GError *error = NULL;
+
+	fid = camel_ews_store_summary_get_folder_id_from_name (ews_store->summary, folder_name);
+	if (!fid)
+		return FALSE;
+
+	if (camel_ews_store_summary_get_foreign (ews_store->summary, fid, &error) && !error) {
+		truth = TRUE;
+	}
+
+	g_clear_error (&error);
+	g_free (fid);
+
+	return truth;
+}
+
+static gboolean
+ews_store_subscribe_folder_sync (CamelSubscribable *subscribable,
+                                 const gchar *folder_name,
+                                 GCancellable *cancellable,
+                                 GError **error)
+{
+	CamelEwsStore *ews_store = CAMEL_EWS_STORE (subscribable);
+
+	if (!camel_offline_store_get_online (CAMEL_OFFLINE_STORE (ews_store))) {
+		g_set_error_literal (
+			error, CAMEL_SERVICE_ERROR, CAMEL_SERVICE_ERROR_UNAVAILABLE,
+			_("Cannot subscribe EWS folders in offline mode"));
+		return FALSE;
+	}
+
+	/* it does nothing currently */
+
+	return TRUE;
+}
+
+static gboolean
+ews_store_unsubscribe_folder_sync (CamelSubscribable *subscribable,
+                                   const gchar *folder_name,
+                                   GCancellable *cancellable,
+                                   GError **error)
+{
+	CamelEwsStore *ews_store = CAMEL_EWS_STORE (subscribable);
+	gboolean res = TRUE;
+	gchar *fid;
+
+	if (!camel_offline_store_get_online (CAMEL_OFFLINE_STORE (ews_store))) {
+		g_set_error_literal (
+			error, CAMEL_SERVICE_ERROR, CAMEL_SERVICE_ERROR_UNAVAILABLE,
+			_("Cannot unsubscribe EWS folders in offline mode"));
+		return FALSE;
+	}
+
+	fid = camel_ews_store_summary_get_folder_id_from_name (ews_store->summary, folder_name);
+	if (!fid) {
+		/* no such folder in the cache, might be unsubscribed already */
+		return TRUE;
+	}
+
+	if (!camel_ews_store_summary_get_foreign (ews_store->summary, fid, NULL)) {
+		/* nothing to do for regular folders */
+		res = TRUE;
+	} else {
+		CamelFolderInfo *fi;
+
+		fi = camel_ews_utils_build_folder_info (ews_store, fid);
+		camel_ews_store_summary_remove_folder (ews_store->summary, fid, error);
+
+		camel_subscribable_folder_unsubscribed (CAMEL_SUBSCRIBABLE (ews_store), fi);
+		camel_store_folder_deleted (CAMEL_STORE (ews_store), fi);
+		camel_folder_info_free (fi);
+
+		camel_ews_store_ensure_virtual_folders (ews_store);
+		camel_ews_store_summary_save (ews_store->summary, NULL);
+	}
+
+	g_free (fid);
+
+	return res;
 }
 
 gboolean
@@ -1234,6 +1604,14 @@ camel_ews_store_class_init (CamelEwsStoreClass *class)
 	store_class->can_refresh_folder = ews_can_refresh_folder;
 }
 
+static void
+camel_ews_subscribable_init (CamelSubscribableInterface *interface)
+{
+	interface->folder_is_subscribed = ews_store_folder_is_subscribed;
+	interface->subscribe_folder_sync = ews_store_subscribe_folder_sync;
+	interface->unsubscribe_folder_sync = ews_store_unsubscribe_folder_sync;
+}
+
 static void
 camel_ews_store_init (CamelEwsStore *ews_store)
 {
