@@ -38,264 +38,6 @@
 #define SUBFOLDER_DIR_NAME     "subfolders"
 #define SUBFOLDER_DIR_NAME_LEN 10
 
-/**
- * e_path_to_physical:
- * @prefix: a prefix to prepend to the path, or %NULL
- * @path: the virtual path to convert to a filesystem path.
- *
- * This converts the "virtual" path @path into an expanded form that
- * allows a given name to refer to both a file and a directory. The
- * expanded path will have a "subfolders" directory inserted between
- * each path component. If the path ends with "/", the returned
- * physical path will end with "/subfolders"
- *
- * If @prefix is non-%NULL, it will be prepended to the returned path.
- *
- * Returns: the expanded path
- **/
-gchar *
-e_path_to_physical (const gchar *prefix,
-                    const gchar *vpath)
-{
-	const gchar *p, *newp;
-	gchar *dp;
-	gchar *ppath;
-	gint ppath_len;
-	gint prefix_len;
-
-	while (*vpath == '/')
-		vpath++;
-	if (!prefix)
-		prefix = "";
-
-	/* Calculate the length of the real path. */
-	ppath_len = strlen (vpath);
-	ppath_len++;	/* For the ending zero.  */
-
-	prefix_len = strlen (prefix);
-	ppath_len += prefix_len;
-	ppath_len++;	/* For the separating slash.  */
-
-	/* Take account of the fact that we need to translate every
-	 * separator into 'subfolders/'.
-	 */
-	p = vpath;
-	while (1) {
-		newp = strchr (p, '/');
-		if (newp == NULL)
-			break;
-
-		ppath_len += SUBFOLDER_DIR_NAME_LEN;
-		ppath_len++; /* For the separating slash.  */
-
-		/* Skip consecutive slashes.  */
-		while (*newp == '/')
-			newp++;
-
-		p = newp;
-	};
-
-	ppath = g_malloc (ppath_len);
-	dp = ppath;
-
-	memcpy (dp, prefix, prefix_len);
-	dp += prefix_len;
-	*(dp++) = '/';
-
-	/* Copy the mangled path.  */
-	p = vpath;
-	while (1) {
-		newp = strchr (p, '/');
-		if (newp == NULL) {
-			strcpy (dp, p);
-			break;
-		}
-
-		memcpy (dp, p, newp - p + 1); /* '+ 1' to copy the slash too.  */
-		dp += newp - p + 1;
-
-		memcpy (dp, SUBFOLDER_DIR_NAME, SUBFOLDER_DIR_NAME_LEN);
-		dp += SUBFOLDER_DIR_NAME_LEN;
-
-		*(dp++) = '/';
-
-		/* Skip consecutive slashes.  */
-		while (*newp == '/')
-			newp++;
-
-		p = newp;
-	}
-
-	return ppath;
-}
-
-static gboolean
-find_folders_recursive (const gchar *physical_path,
-                        const gchar *path,
-                        EPathFindFoldersCallback callback,
-                        gpointer data)
-{
-	GDir *dir;
-	gchar *subfolder_directory_path;
-	gboolean ok;
-
-	if (*path) {
-		if (!callback (physical_path, path, data))
-			return FALSE;
-
-		subfolder_directory_path = g_strdup_printf ("%s/%s", physical_path, SUBFOLDER_DIR_NAME);
-	} else {
-		/* On the top level, we have no folders and,
-		 * consequently, no subfolder directory.
-		 */
-
-		subfolder_directory_path = g_strdup (physical_path);
-	}
-
-	/* Now scan the subfolders and load them. */
-	dir = g_dir_open (subfolder_directory_path, 0, NULL);
-	if (dir == NULL) {
-		g_free (subfolder_directory_path);
-		return TRUE;
-	}
-
-	ok = TRUE;
-	while (ok) {
-		struct stat file_stat;
-		const gchar *dirent;
-		gchar *file_path;
-		gchar *new_path;
-
-		dirent = g_dir_read_name (dir);
-		if (dirent == NULL)
-			break;
-
-		file_path = g_strdup_printf ("%s/%s", subfolder_directory_path, dirent);
-
-		if (g_stat (file_path, &file_stat) < 0 ||
-		    !S_ISDIR (file_stat.st_mode)) {
-			g_free (file_path);
-			continue;
-		}
-
-		new_path = g_strdup_printf ("%s/%s", path, dirent);
-
-		ok = find_folders_recursive (file_path, new_path, callback, data);
-
-		g_free (file_path);
-		g_free (new_path);
-	}
-
-	g_dir_close (dir);
-	g_free (subfolder_directory_path);
-
-	return ok;
-}
-
-/**
- * e_path_find_folders:
- * @prefix: directory to start from
- * @callback: Callback to invoke on each folder
- * @data: Data for @callback
- *
- * Walks the folder tree starting at @prefix and calls @callback
- * on each folder.
- *
- * Returns: %TRUE on success, %FALSE if an error occurs at any point
- **/
-gboolean
-e_path_find_folders (const gchar *prefix,
-                     EPathFindFoldersCallback callback,
-                     gpointer data)
-{
-	return find_folders_recursive (prefix, "", callback, data);
-}
-
-/**
- * e_path_rmdir:
- * @prefix: a prefix to prepend to the path, or %NULL
- * @path: the virtual path to convert to a filesystem path.
- *
- * This removes the directory pointed to by @prefix and @path
- * and attempts to remove its parent "subfolders" directory too
- * if it's empty.
- *
- * Returns: -1 (with errno set) if it failed to rmdir the
- * specified directory. 0 otherwise, whether or not it removed
- * the parent directory.
- **/
-gint
-e_path_rmdir (const gchar *prefix,
-              const gchar *vpath)
-{
-	gchar *physical_path, *p;
-
-	/* Remove the directory itself */
-	physical_path = e_path_to_physical (prefix, vpath);
-	if (g_rmdir (physical_path) == -1) {
-		g_free (physical_path);
-		return -1;
-	}
-
-	/* Attempt to remove its parent "subfolders" directory,
-	 * ignoring errors since it might not be empty.
-	 */
-
-	p = strrchr (physical_path, '/');
-	if (p[1] == '\0') {
-		g_free (physical_path);
-		return 0;
-	}
-	*p = '\0';
-	p = strrchr (physical_path, '/');
-	if (!p || strcmp (p + 1, SUBFOLDER_DIR_NAME) != 0) {
-		g_free (physical_path);
-		return 0;
-	}
-
-	g_rmdir (physical_path);
-	g_free (physical_path);
-	return 0;
-}
-
-void
-do_flags_diff (flags_diff_t *diff,
-               guint32 old,
-               guint32 _new)
-{
-	diff->changed = old ^ _new;
-	diff->bits = _new & diff->changed;
-}
-
-gchar *
-ews_concat (const gchar *prefix,
-            const gchar *suffix)
-{
-	gsize len;
-
-	len = strlen (prefix);
-	if (len == 0 || prefix[len - 1] == '/')
-		return g_strdup_printf ("%s%s", prefix, suffix);
-	else
-		return g_strdup_printf ("%s%c%s", prefix, '/', suffix);
-}
-
-void
-strip_lt_gt (gchar **string,
-             gint s_offset,
-             gint e_offset)
-{
-	gchar *temp = NULL;
-	gint len;
-
-	temp = g_strdup (*string);
-	len = strlen (*string);
-
-	*string = (gchar *)g_malloc0 (len-1);
-	*string = memcpy(*string, temp+s_offset, len-e_offset);
-	g_free (temp);
-}
-
 CamelFolderInfo *
 camel_ews_utils_build_folder_info (CamelEwsStore *store,
                                    const gchar *fid)
@@ -334,12 +76,17 @@ sync_deleted_folders (CamelEwsStore *store,
 		if (!camel_ews_store_summary_has_folder (ews_summary, fid))
 			continue;
 
-		ftype = camel_ews_store_summary_get_folder_type (ews_summary, fid, NULL);
+		ftype = camel_ews_store_summary_get_folder_type (
+			ews_summary, fid, NULL);
 		if (ftype == E_EWS_FOLDER_TYPE_MAILBOX) {
 			fi = camel_ews_utils_build_folder_info (store, fid);
 
-			camel_ews_store_summary_remove_folder (ews_summary, fid, &error);
-			camel_store_folder_deleted ((CamelStore *) store, fi);
+			camel_ews_store_summary_remove_folder (
+				ews_summary, fid, &error);
+
+			camel_subscribable_folder_unsubscribed (
+				CAMEL_SUBSCRIBABLE (store), fi);
+			camel_store_folder_deleted (CAMEL_STORE (store), fi);
 
 			g_clear_error (&error);
 		}
@@ -361,13 +108,15 @@ ews_utils_rename_folder (CamelEwsStore *store,
 
 	camel_ews_store_summary_set_change_key (ews_summary, fid, changekey);
 	if (display_name)
-		camel_ews_store_summary_set_folder_name (ews_summary, fid, display_name);
+		camel_ews_store_summary_set_folder_name (
+			ews_summary, fid, display_name);
 	if (pfid)
-		camel_ews_store_summary_set_parent_folder_id (ews_summary, fid, pfid);
+		camel_ews_store_summary_set_parent_folder_id (
+			ews_summary, fid, pfid);
 
 	if (ftype == E_EWS_FOLDER_TYPE_MAILBOX) {
 		fi = camel_ews_utils_build_folder_info (store, fid);
-		camel_store_folder_renamed ((CamelStore *) store, old_fname, fi);
+		camel_store_folder_renamed (CAMEL_STORE (store), old_fname, fi);
 	}
 
 	return TRUE;
@@ -381,7 +130,7 @@ sync_updated_folders (CamelEwsStore *store,
 	GSList *l;
 
 	for (l = updated_folders; l != NULL; l = g_slist_next (l)) {
-		EEwsFolder *ews_folder = (EEwsFolder *)	l->data;
+		EEwsFolder *ews_folder = (EEwsFolder *) l->data;
 		EEwsFolderType ftype;
 		gchar *folder_name;
 		gchar *display_name;
@@ -392,7 +141,8 @@ sync_updated_folders (CamelEwsStore *store,
 			continue;
 
 		fid = e_ews_folder_get_id (ews_folder);
-		folder_name = camel_ews_store_summary_get_folder_full_name (ews_summary, fid->id, NULL);
+		folder_name = camel_ews_store_summary_get_folder_full_name (
+			ews_summary, fid->id, NULL);
 
 		pfid = e_ews_folder_get_parent_id (ews_folder);
 		display_name = g_strdup (e_ews_folder_get_name (ews_folder));
@@ -415,12 +165,14 @@ sync_updated_folders (CamelEwsStore *store,
 				if (!display_name)
 					goto done;
 
-				pfname = camel_ews_store_summary_get_folder_full_name (ews_summary, pfid->id, NULL);
+				pfname = camel_ews_store_summary_get_folder_full_name (
+					ews_summary, pfid->id, NULL);
 
 				/* If the lookup failed, it'll be because the new parent folder
 				 * is the message folder root. */
 				if (pfname) {
-					new_fname = g_strconcat (pfname, "/", display_name, NULL);
+					new_fname = g_strconcat (
+						pfname, "/", display_name, NULL);
 					g_free (pfname);
 				} else
 					new_fname = g_strdup (display_name);
@@ -476,8 +228,10 @@ add_folder_to_summary (CamelEwsStore *store,
 	camel_ews_store_summary_new_folder (
 		ews_summary, fid->id,
 		pfid->id, fid->change_key,
-		dname, ftype, 0, total);
-	camel_ews_store_summary_set_folder_unread (ews_summary, fid->id, unread);
+		dname, ftype, 0, total,
+		e_ews_folder_get_foreign (folder));
+	camel_ews_store_summary_set_folder_unread (
+		ews_summary, fid->id, unread);
 }
 
 static void
@@ -506,8 +260,12 @@ sync_created_folders (CamelEwsStore *ews_store,
 		add_folder_to_summary (ews_store, folder);
 
 		if (ftype == E_EWS_FOLDER_TYPE_MAILBOX) {
-			fi = camel_ews_utils_build_folder_info (ews_store, fid->id);
-			camel_store_folder_created ((CamelStore *) ews_store, fi);
+			fi = camel_ews_utils_build_folder_info (
+				ews_store, fid->id);
+			camel_store_folder_created (
+				CAMEL_STORE (ews_store), fi);
+			camel_subscribable_folder_subscribed (
+				CAMEL_SUBSCRIBABLE (ews_store), fi);
 			camel_folder_info_free (fi);
 		}
 	}
@@ -527,16 +285,18 @@ ews_utils_sync_folders (CamelEwsStore *ews_store,
 
 	camel_ews_store_summary_save (ews_store->summary, &error);
 	if (error != NULL) {
-		g_print ("Error while saving store summary %s \n", error->message);
+		g_print (
+			"Error while saving store summary %s \n",
+			error->message);
 		g_clear_error (&error);
 	}
-	return;
 }
 
 void
 camel_ews_utils_sync_deleted_items (CamelEwsFolder *ews_folder,
                                     GSList *items_deleted)
 {
+	CamelStore *store;
 	CamelFolder *folder;
 	const gchar *full_name;
 	CamelFolderChangeInfo *ci;
@@ -545,22 +305,27 @@ camel_ews_utils_sync_deleted_items (CamelEwsFolder *ews_folder,
 	GList *items_deleted_list = NULL;
 
 	ci = camel_folder_change_info_new ();
-	ews_store = (CamelEwsStore *) camel_folder_get_parent_store ((CamelFolder *) ews_folder);
 
-	folder = (CamelFolder *) ews_folder;
+	folder = CAMEL_FOLDER (ews_folder);
 	full_name = camel_folder_get_full_name (folder);
 
+	store = camel_folder_get_parent_store (folder);
+	ews_store = CAMEL_EWS_STORE (store);
+
 	for (l = items_deleted; l != NULL; l = g_slist_next (l)) {
 		const gchar *id = l->data;
 
-		items_deleted_list = g_list_prepend (items_deleted_list, (gpointer) id);
+		items_deleted_list = g_list_prepend (
+			items_deleted_list, (gpointer) id);
 
 		camel_folder_summary_remove_uid (folder->summary, id);
 		camel_folder_change_info_remove_uid (ci, id);
 	}
 
 	items_deleted_list = g_list_reverse (items_deleted_list);
-	camel_db_delete_uids (((CamelStore *) ews_store)->cdb_w, full_name, items_deleted_list, NULL);
+	camel_db_delete_uids (
+		CAMEL_STORE (ews_store)->cdb_w,
+		full_name, items_deleted_list, NULL);
 	g_list_free (items_deleted_list);
 
 	if (camel_folder_change_info_changed (ci)) {
@@ -795,7 +560,9 @@ ews_set_threading_data (CamelEwsMessageInfo *mi,
 	msgid = camel_header_msgid_decode (message_id);
 	if (msgid) {
 		digest = get_md5_digest ((const guchar *) msgid);
-		memcpy (mi->info.message_id.id.hash, digest, sizeof (mi->info.message_id.id.hash));
+		memcpy (
+			mi->info.message_id.id.hash,
+			digest, sizeof (mi->info.message_id.id.hash));
 		g_free (digest);
 		g_free (msgid);
 	}
@@ -815,13 +582,17 @@ ews_set_threading_data (CamelEwsMessageInfo *mi,
 		return;
 
 	count = camel_header_references_list_size (&refs);
-	mi->info.references = g_malloc (sizeof (*mi->info.references) + ((count - 1) * sizeof (mi->info.references->references[0])));
+	mi->info.references = g_malloc (
+		sizeof (*mi->info.references) + ((count - 1) *
+		sizeof (mi->info.references->references[0])));
 	scan = refs;
 	count = 0;
 
 	while (scan) {
 		digest = get_md5_digest ((const guchar *) scan->id);
-		memcpy (mi->info.references->references[count].id.hash, digest, sizeof (mi->info.message_id.id.hash));
+		memcpy (
+			mi->info.references->references[count].id.hash,
+			digest, sizeof (mi->info.message_id.id.hash));
 		g_free (digest);
 
 		count++;
@@ -841,7 +612,7 @@ camel_ews_utils_sync_updated_items (CamelEwsFolder *ews_folder,
 	GSList *l;
 
 	ci = camel_folder_change_info_new ();
-	folder = (CamelFolder *) ews_folder;
+	folder = CAMEL_FOLDER (ews_folder);
 
 	for (l = items_updated; l != NULL; l = g_slist_next (l)) {
 		EEwsItem *item = (EEwsItem *) l->data;
@@ -854,7 +625,8 @@ camel_ews_utils_sync_updated_items (CamelEwsFolder *ews_folder,
 		}
 
 		id = e_ews_item_get_id (item);
-		mi = (CamelEwsMessageInfo *) camel_folder_summary_get (folder->summary, id->id);
+		mi = (CamelEwsMessageInfo *)
+			camel_folder_summary_get (folder->summary, id->id);
 		if (mi) {
 			gint server_flags;
 
@@ -880,7 +652,7 @@ camel_ews_utils_sync_updated_items (CamelEwsFolder *ews_folder,
 	if (camel_folder_change_info_changed (ci)) {
 		camel_folder_summary_touch (folder->summary);
 		camel_folder_summary_save_to_db (folder->summary, NULL);
-		camel_folder_changed ((CamelFolder *) ews_folder, ci);
+		camel_folder_changed (CAMEL_FOLDER (ews_folder), ci);
 	}
 	camel_folder_change_info_free (ci);
 	g_slist_free (items_updated);
@@ -899,7 +671,7 @@ camel_ews_utils_sync_created_items (CamelEwsFolder *ews_folder,
 		return;
 
 	ci = camel_folder_change_info_new ();
-	folder = (CamelFolder *) ews_folder;
+	folder = CAMEL_FOLDER (ews_folder);
 
 	for (l = items_created; l != NULL; l = g_slist_next (l)) {
 		EEwsItem *item = (EEwsItem *) l->data;
@@ -920,18 +692,23 @@ camel_ews_utils_sync_created_items (CamelEwsFolder *ews_folder,
 		}
 
 		id = e_ews_item_get_id (item);
-		mi = (CamelEwsMessageInfo *) camel_folder_summary_get (folder->summary, id->id);
+		mi = (CamelEwsMessageInfo *)
+			camel_folder_summary_get (folder->summary, id->id);
 		if (mi) {
 			camel_message_info_free (mi);
 			g_object_unref (item);
 			continue;
 		}
 
-		mi = (CamelEwsMessageInfo *) camel_message_info_new (folder->summary);
+		mi = (CamelEwsMessageInfo *)
+			camel_message_info_new (folder->summary);
 
 		if (mi->info.content == NULL) {
-			mi->info.content = camel_folder_summary_content_info_new (folder->summary);
-			mi->info.content->type = camel_content_type_new ("multipart", "mixed");
+			mi->info.content =
+				camel_folder_summary_content_info_new (
+				folder->summary);
+			mi->info.content->type =
+				camel_content_type_new ("multipart", "mixed");
 		}
 
 		item_type = e_ews_item_get_item_type (item);
@@ -940,11 +717,13 @@ camel_ews_utils_sync_created_items (CamelEwsFolder *ews_folder,
 			 item_type == E_EWS_ITEM_TYPE_MEETING_REQUEST ||
 			 item_type == E_EWS_ITEM_TYPE_MEETING_RESPONSE ||
 			 item_type == E_EWS_ITEM_TYPE_MEETING_RESPONSE)
-			camel_message_info_set_user_flag ((CamelMessageInfo *) mi, "$has_cal", TRUE);
+			camel_message_info_set_user_flag (
+				(CamelMessageInfo *) mi, "$has_cal", TRUE);
 
 		mi->info.uid = camel_pstring_strdup (id->id);
 		mi->info.size = e_ews_item_get_size (item);
-		mi->info.subject = camel_pstring_strdup (e_ews_item_get_subject (item));
+		mi->info.subject = camel_pstring_strdup (
+			e_ews_item_get_subject (item));
 		mi->item_type = item_type;
 		mi->change_key = g_strdup (id->change_key);
 
@@ -973,7 +752,8 @@ camel_ews_utils_sync_created_items (CamelEwsFolder *ews_folder,
 		mi->info.flags |= server_flags;
 		mi->server_flags = server_flags;
 
-		camel_folder_summary_add (folder->summary, (CamelMessageInfo *) mi);
+		camel_folder_summary_add (
+			folder->summary, (CamelMessageInfo *) mi);
 
 		/* camel_folder_summary_add() sets folder_flagged flag
 		 * on the message info, but this is a fresh item downloaded
@@ -991,7 +771,7 @@ camel_ews_utils_sync_created_items (CamelEwsFolder *ews_folder,
 	if (camel_folder_change_info_changed (ci)) {
 		camel_folder_summary_touch (folder->summary);
 		camel_folder_summary_save_to_db (folder->summary, NULL);
-		camel_folder_changed ((CamelFolder *) ews_folder, ci);
+		camel_folder_changed (CAMEL_FOLDER (ews_folder), ci);
 	}
 	camel_folder_change_info_free (ci);
 	g_slist_free (items_created);
