@@ -114,11 +114,19 @@ fetch_ns (ESoapMessage *msg,
 	xmlNsPtr ns = NULL;
 
 	if (prefix && ns_uri)
-		ns = xmlNewNs (priv->last_node, (const xmlChar *) ns_uri, (const xmlChar *) prefix);
+		ns = xmlNewNs (
+			priv->last_node,
+			(const xmlChar *) ns_uri,
+			(const xmlChar *) prefix);
 	else if (prefix && !ns_uri) {
-		ns = xmlSearchNs (priv->doc, priv->last_node, (const xmlChar *) prefix);
+		ns = xmlSearchNs (
+			priv->doc, priv->last_node,
+			(const xmlChar *) prefix);
 		if (!ns)
-			ns = xmlNewNs (priv->last_node, (const xmlChar *) "", (const xmlChar *) prefix);
+			ns = xmlNewNs (
+				priv->last_node,
+				(const xmlChar *) "",
+				(const xmlChar *) prefix);
 	}
 
 	return ns;
@@ -468,7 +476,7 @@ e_soap_message_start_envelope (ESoapMessage *msg)
 		(const xmlChar *) "SOAP-ENC");
 	xmlNewNs (
 		msg->priv->doc->xmlRootNode,
-		(const xmlChar *) "http://www.w3.org/1999/XMLSchema",
+		(const xmlChar *) "http://www.w3.org/2001/XMLSchema",
 		(const xmlChar *) "xsd");
 	xmlNewNs (
 		msg->priv->doc->xmlRootNode,
@@ -476,7 +484,7 @@ e_soap_message_start_envelope (ESoapMessage *msg)
 		(const xmlChar *) "SOAP-ENV");
 	msg->priv->xsi_ns = xmlNewNs (
 		msg->priv->doc->xmlRootNode,
-		(const xmlChar *) "http://www.w3.org/1999/XMLSchema-instance",
+		(const xmlChar *) "http://www.w3.org/2001/XMLSchema-instance",
 		(const xmlChar *) "xsi");
 }
 
